%global libzen_version	0.4.41

Name:		mediainfo
Version:	24.03
Release:	%mkrel 2
Summary:	Supplies technical and tag information about a video or audio file
Group:		Sound/Utilities
License:	BSD
URL:		https://mediaarea.net/
Source0:	https://mediaarea.net/download/source/mediainfo/%{version}/mediainfo_%{version}.tar.bz2
BuildRequires:	pkgconfig(libmediainfo) >= %{version}
BuildRequires:	pkgconfig(libzen) >= %{libzen_version}
BuildRequires:	pkgconfig(zlib)
BuildRequires:	dos2unix
BuildRequires:	wxgtk-devel
BuildRequires:	cmake(Qt6Core)
BuildRequires:	cmake(Qt6Gui)
BuildRequires:	cmake(Qt6Network)
BuildRequires:	cmake(Qt6Widgets)
BuildRequires:	cmake(Qt6Xml)
BuildRequires:	imagemagick

%description
MediaInfo supplies technical and tag information about a video or audio file.

What information can I get from MediaInfo?
* General: title, author, director, album, track number, date, duration...
* Video: codec, aspect, fps, bitrate...
* Audio: codec, sample rate, channels, language, bitrate...
* Text: language of subtitle
* Chapters: number of chapters, list of chapters

AV1, DivX, XviD, H263, H.263, H264, x264, ASP, AVC, iTunes, MPEG-1,
MPEG1, MPEG-2, MPEG2, MPEG-4, MPEG4, MP4, M4A, M4V, QuickTime,
RealVideo, RealAudio, RA, RM, MSMPEG4v1, MSMPEG4v2, MSMPEG4v3,
VOB, DVD, WMA, VMW, ASF, 3GP, 3GPP, 3GP2

What format (container) does MediaInfo support?
* Video: MKV, OGM, AVI, DivX, WMV, QuickTime, Real, MPEG-1,
  MPEG-2, MPEG-4, DVD (VOB) (Codecs: DivX, XviD, MSMPEG4, ASP,
  H.264, AVC...)
* Audio: OGG, MP3, WAV, RA, AC3, DTS, AAC, M4A, AU, AIFF
* Subtitles: SRT, SSA, ASS, SAMI

%package gui-wx
Summary:	wx-based GUI for %{name}
Group:		Sound/Utilities
Requires:	%{name}-gui-common = %{version}-%{release}
Provides:	%{name}-gui = %{version}-%{release}

%description gui-wx
wx-based graphical user interface for %{name}.

%package gui-qt
Summary:	Qt-based GUI for %{name}
Group:		Sound/Utilities
Requires:	%{name}-gui-common = %{version}-%{release}
Provides:	%{name}-gui = %{version}-%{release}
#The PLASMA service menu runs kdialog
Recommends:	kdialog

%description gui-qt
Qt-based graphical user interface for %{name}.

%package gui-common
Summary:	Common files for %{name} GUIs
Group:		Sound/Utilities
BuildArch:	noarch

%description gui-common
Common files for %{name} GUI packages.

%prep
%setup -q -n MediaInfo

# fix EOLs and rights
dos2unix License.html History_*.txt
chmod 644 *.html *.txt Release/*.txt

%build
# build CLI
pushd Project/GNU/CLI
	autoreconf -vfi
	%configure --disable-static
	%make_build
popd

# now build GUI
pushd Project/GNU/GUI
	autoreconf -vfi
	%configure --disable-static
	%make_build
popd

# now build Qt GUI
pushd Project/QMake/GUI
%if %mgaver >= 10
%ifarch %{ix86}
export CFLAGS="%{build_cflags} -mfpmath=sse -msse2"
export CXXFLAGS="%{build_cxxflags} -mfpmath=sse -msse2"
%endif
%endif
	%qmake_qt6
	%make_build
popd

%install
pushd Project/GNU/CLI
	%make_install
popd

pushd Project/GNU/GUI
	%make_install
popd

pushd Project/QMake/GUI
	# as of 18.08.1 it overwrites the Wx binary
	#make_install INSTALL_ROOT=%%{buildroot}
	install -m 755 %{name}-gui %{buildroot}%{_bindir}/%{name}-qt
popd

# icon
for i in 16 32 48 64 128; do
	mkdir -p %{buildroot}%{_datadir}/icons/hicolor/${i}x${i}/apps/
	convert -scale ${i} Source/Resource/Image/MediaInfo.png %{buildroot}%{_datadir}/icons/hicolor/${i}x${i}/apps/%{name}.png
done

# menu-entry for QT gui
mkdir -p %{buildroot}%{_datadir}/applications/
cat > %{buildroot}%{_datadir}/applications/%{name}-qt.desktop << EOF
[Desktop Entry]
Type=Application
Name=MediaInfo
Comment=Supplies technical and tag information about a video or audio file
Comment[fr]=fournit des informations techniques et les tags à propos de vos fichiers video et audio
Icon=%{name}
Exec=%{name}-qt %f
Terminal=false
Categories=AudioVideo;AudioVideoEditing;Qt;
MimeType=video/mpeg;video/x-mpeg;video/msvideo;video/quicktime;video/x-anim;video/x-avi;video/x-ms-asf;video/x-ms-wmv;video/x-msvideo;video/x-nsv;video/x-flc;video/x-fli;video/x-flv;video/vnd.rn-realvideo;video/mp4;video/mp4v-es;video/mp2t;application/ogg;application/x-ogg;video/x-ogm+ogg;audio/x-vorbis+ogg;application/x-matroska;audio/x-matroska;video/x-matroska;video/webm;audio/webm;audio/x-mp3;audio/x-mpeg;audio/mpeg;audio/x-wav;audio/x-mpegurl;audio/x-scpls;audio/x-m4a;audio/x-ms-asf;audio/x-ms-asx;audio/x-ms-wax;application/vnd.rn-realmedia;audio/x-real-audio;audio/x-pn-realaudio;application/x-flac;audio/x-flac;application/x-shockwave-flash;audio/vnd.rn-realaudio;audio/x-pn-aiff;audio/x-pn-au;audio/x-pn-wav;audio/x-pn-windows-acm;application/x-extension-mp4;audio/mp4;audio/amr;audio/amr-wb;application/x-shorten;audio/x-ape;audio/x-wavpack;audio/x-tta;audio/x-opus+ogg;
Keywords=mediainfo;metadata;tag;video;audio;subtitles;chapters;codec;mkv;mpeg;mp3;h264;avc;h265;hevc;avi;
EOF

# unneeded
rm -rf %{buildroot}%{_datadir}/apps/konqueror/servicemenus/%{name}-gui.desktop
rm -rf %{buildroot}%{_datadir}/kde4/services/ServiceMenus/%{name}-gui.desktop

# fix service menu
mkdir -p %{buildroot}%{_datadir}/kio/servicemenus
mv %{buildroot}%{_datadir}/kservices5/ServiceMenus/%{name}-gui.desktop \
  %{buildroot}%{_datadir}/kio/servicemenus/%{name}-qt.desktop

sed -i \
  -e 's|\(^Exec=\).*|\1kdialog -msgbox "$\(mediainfo-qt %u\)"|g' \
  -e 's|%{name}-gui|%{name}-qt|g' \
    %{buildroot}%{_datadir}/kio/servicemenus/%{name}-qt.desktop

%files
%doc Release/ReadMe_CLI_Linux.txt
%doc License.html History_CLI.txt
%{_bindir}/mediainfo

%files gui-wx
%doc Release/ReadMe_GUI_Linux.txt
%doc License.html History_GUI.txt
%{_bindir}/%{name}-gui
%{_datadir}/applications/%{name}-gui.desktop

%files gui-common
%{_datadir}/icons/hicolor/*/apps/*.png
%{_datadir}/icons/hicolor/scalable/apps/mediainfo.svg
%{_datadir}/pixmaps/mediainfo.xpm
%{_metainfodir}/%{name}-gui.metainfo.xml

%files gui-qt
%{_bindir}/%{name}-qt
%{_datadir}/applications/%{name}-qt.desktop
%{_datadir}/kio/servicemenus/%{name}-qt.desktop


%changelog
* Mon Apr 01 2024 daviddavid <daviddavid> 24.03-2.mga10
+ Revision: 2053671
- new version: 24.03
- switch to Qt6
- install servimenus file to new plasma6 kio/servicemenus dir

* Wed Feb 14 2024 daviddavid <daviddavid> 24.01-1.mga10
+ Revision: 2041167
- new version: 24.01

* Mon Jan 01 2024 daviddavid <daviddavid> 23.11-1.mga10
+ Revision: 2024960
- new version: 23.11

* Wed Sep 20 2023 daviddavid <daviddavid> 23.09-1.mga10
+ Revision: 1988753
- new version: 23.09

* Mon Sep 04 2023 daviddavid <daviddavid> 23.07-1.mga10
+ Revision: 1984085
- new version: 23.07

* Fri Dec 23 2022 daviddavid <daviddavid> 22.12-1.mga9
+ Revision: 1926099
- new version: 22.12

* Wed Nov 23 2022 daviddavid <daviddavid> 22.09-1.mga9
+ Revision: 1910638
- new version: 22.09

* Fri Jul 15 2022 wally <wally> 21.09-5.mga9
+ Revision: 1868993
- rebuild for wxgtk 3.2.0

* Sun Jun 12 2022 wally <wally> 21.09-4.mga9
+ Revision: 1864101
- rebuild for wxgtk 3.1.7

* Fri Apr 15 2022 wally <wally> 21.09-3.mga9
+ Revision: 1849958
- rebuild for wxgtk 3.1.6

* Mon Apr 04 2022 umeabot <umeabot> 21.09-2.mga9
+ Revision: 1842914
- Mageia 9 Mass Rebuild

* Sun Jan 30 2022 mrambo3501 <mrambo3501> 21.09-1.mga9
+ Revision: 1770517
- version 21.09

* Sat Jan 15 2022 wally <wally> 21.03-3.mga9
+ Revision: 1768514
- rebuild for wxgtk 3.1.5 with working wxSizer::SetSizeHints()

* Sat Jan 01 2022 wally <wally> 21.03-2.mga9
+ Revision: 1765713
- rebuild for wxgtk 3.1.5 to resolve 'Symbol X has different size in shared object, consider re-linking' error

* Thu Apr 01 2021 daviddavid <daviddavid> 21.03-1.mga9
+ Revision: 1712290
- new version: 21.03

* Fri Jan 01 2021 wally <wally> 20.09-2.mga8
+ Revision: 1667705
- rebuild for wxgtk pre 3.1.5 snapshot

* Sun Nov 08 2020 daviddavid <daviddavid> 20.09-1.mga8
+ Revision: 1643659
- new version: 20.09

* Sun Aug 16 2020 wally <wally> 20.08-2.mga8
+ Revision: 1614345
- rebuild for new wxgtk 3.1.4

* Thu Aug 13 2020 daviddavid <daviddavid> 20.08-1.mga8
+ Revision: 1613911
- new version: 20.08

* Mon Apr 06 2020 zezinho <zezinho> 20.03-1.mga8
+ Revision: 1565264
- new version

* Mon Feb 24 2020 zezinho <zezinho> 19.09-4.mga8
+ Revision: 1550100
- switch Suggests to Recommends

* Tue Feb 18 2020 umeabot <umeabot> 19.09-3.mga8
+ Revision: 1538017
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Tue Nov 12 2019 wally <wally> 19.09-2.mga8
+ Revision: 1459470
- rebuild for wxgtk 3.1.3

* Mon Sep 23 2019 zezinho <zezinho> 19.09-1.mga8
+ Revision: 1444758
- new version: 19.09

* Wed Jul 17 2019 daviddavid <daviddavid> 19.07-1.mga8
+ Revision: 1422136
- new version: 19.07

* Fri Jul 12 2019 daviddavid <daviddavid> 19.04-1.mga8
+ Revision: 1420548
- new version: 19.04

* Mon Jul 08 2019 wally <wally> 18.12-4.mga8
+ Revision: 1419543
- rebuild for wxgtk 3.1.2 with 2.8 compatibility

* Mon Jul 08 2019 wally <wally> 18.12-3.mga8
+ Revision: 1419509
- rebuild with gtk3 enabled wxgtk 3.1.2

* Sun Mar 31 2019 umeabot <umeabot> 18.12-2.mga7
+ Revision: 1383374
- Qt5 Rebuild

* Mon Feb 04 2019 zezinho <zezinho> 18.12-1.mga7
+ Revision: 1363226
- new version 18.12

* Sun Oct 28 2018 zezinho <zezinho> 18.08.1-1.mga7
+ Revision: 1326430
- new version 18.08.1 - switch to Qt5 - switch to WxGTK 3.0

* Sun Sep 23 2018 umeabot <umeabot> 17.10-2.mga7
+ Revision: 1299509
- Mageia 7 Mass Rebuild

* Wed Dec 06 2017 wally <wally> 17.10-1.mga7
+ Revision: 1181504
- new version 17.10

* Sun Oct 15 2017 wally <wally> 0.7.99-1.mga7
+ Revision: 1172171
- new version 0.7.99

* Wed May 17 2017 zezinho <zezinho> 0.7.95-1.mga6
+ Revision: 1102449
- add new svg icon and remove kde4 service menu
- fix file list
- new version

* Tue May 10 2016 tv <tv> 0.7.85-2.mga6
+ Revision: 1012074
- switch to FC patch for Qt build fix

* Tue May 10 2016 tv <tv> 0.7.85-1.mga6
+ Revision: 1012065
- use std build macros
- new release

* Thu Dec 31 2015 wally <wally> 0.7.80-1.mga6
+ Revision: 917160
- new version 0.7.80

* Sat Aug 29 2015 cjw <cjw> 0.7.76-2.mga6
+ Revision: 870814
- rebuild with gcc 5

* Thu Aug 13 2015 wally <wally> 0.7.76-1.mga6
+ Revision: 864483
- new version 0.7.76

* Thu Jun 25 2015 wally <wally> 0.7.74-1.mga6
+ Revision: 843522
- new version 0.7.74

* Wed Oct 15 2014 umeabot <umeabot> 0.7.70-3.mga5
+ Revision: 751209
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.7.70-2.mga5
+ Revision: 682333
- Mageia 5 Mass Rebuild

* Sat Sep 06 2014 wally <wally> 0.7.70-1.mga5
+ Revision: 672516
- new version 0.7.70

* Sun May 11 2014 wally <wally> 0.7.69-1.mga5
+ Revision: 621953
- new version 0.7.69

* Sat Apr 26 2014 wally <wally> 0.7.68-1.mga5
+ Revision: 618229
- new version 0.7.68

* Wed Feb 05 2014 wally <wally> 0.7.67-1.mga5
+ Revision: 583444
- new version 0.7.67

* Sat Oct 19 2013 umeabot <umeabot> 0.7.64-2.mga4
+ Revision: 529318
- Mageia 4 Mass Rebuild

* Mon Jul 08 2013 wally <wally> 0.7.64-1.mga4
+ Revision: 451456
- new version 0.7.64
- update URL

* Tue May 28 2013 wally <wally> 0.7.63-1.mga4
+ Revision: 429676
- new version 0.7.63
- switched to BSD-2-Clause license
- rediff P0 to fix qt gui build (from Frugalware)

* Sat Jan 12 2013 umeabot <umeabot> 0.7.61-2.mga3
+ Revision: 359890
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Nov 07 2012 fwang <fwang> 0.7.61-1.mga3
+ Revision: 315934
- update rpm group
- new version 0.7.61

* Mon Sep 03 2012 wally <wally> 0.7.60-1.mga3
+ Revision: 287652
- new version 0.7.60

* Sat Aug 11 2012 wally <wally> 0.7.59-1.mga3
+ Revision: 280541
- new version 0.7.59

* Sat Jun 02 2012 wally <wally> 0.7.58-1.mga3
+ Revision: 253442
- new version 0.7.58

* Tue May 29 2012 luigiwalser <luigiwalser> 0.7.57-1.mga3
+ Revision: 248858
- 0.7.57
- rediff patch0

* Thu Feb 02 2012 wally <wally> 0.7.53-1.mga2
+ Revision: 204078
- new version 0.7.53
- rediff P0

* Sat Dec 24 2011 wally <wally> 0.7.52-1.mga2
+ Revision: 187207
- new version 0.7.52

* Fri Nov 11 2011 wally <wally> 0.7.51-1.mga2
+ Revision: 166781
- new version 0.7.51
- redo P0

* Tue Sep 27 2011 wally <wally> 0.7.50-1.mga2
+ Revision: 149630
- new version 0.7.50
- new version 0.7.48
- add service menu entry for KDE4 (mga#2402)
+ ahmad <ahmad>
- Rebuild against wxgtk2.8 with enabled catch_segvs

* Mon Jul 18 2011 wally <wally> 0.7.47-1.mga2
+ Revision: 125992
- new version 0.7.47
- new version 0.7.46

* Sun Jun 19 2011 wally <wally> 0.7.45-1.mga2
+ Revision: 109993
- fix summaries and descriptions for GUI packages
- imported package mediainfo


* Sat Jun 18 2011 Jani Välimaa <wally@mandriva.org> 0.7.45-1mdv2011.0
+ Revision: 685928
- import mediainfo

